#
# spec file for package xournalpp
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xournalpp
Version:        1.0.18
Release:        lp152.1.2
Summary:        Notetaking software designed around a tablet
License:        GPL-2.0-or-later
Group:          Productivity/Office/Other
URL:            https://github.com/xournalpp/xournalpp
Source0:        https://github.com/xournalpp/xournalpp/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM xournalpp-fix-desktop-categories.patch badshah400@gmail.com -- Fix desktop categories with additional keywords to prevent "No sufficient Category definition" error from brp-desktop.
Patch0:         xournalpp-fix-desktop-categories.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  texlive-latex-bin
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(portaudiocpp)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(zlib)
Requires:       texlive-latex-bin

%description
Xournal++ is a hand note taking software.
It supports pen input, e.g. Wacom tablets.

%lang_package

%prep
%setup -q
%patch0 -p1

%build
%cmake

%install
%cmake_install

# REMOVE UNNECESSARY SCRIPTS update-icon-cache IS TAKEN CARE OF BY RPM FILE TRIGGERS
rm %{buildroot}%{_datadir}/%{name}/ui/*/hicolor/update-icon-cache.sh

%find_lang xournalpp %{no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/xournal-thumbnailer
%{_bindir}/xournalpp
%{_datadir}/applications/*.xournalpp.desktop
%{_datadir}/icons/hicolor/scalable/mimetypes/*.svg
%{_datadir}/mime/packages/*.xml
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/*.appdata.xml
%dir %{_datadir}/mimelnk
%dir %{_datadir}/mimelnk/application
%{_datadir}/mimelnk/application/*.desktop
%{_datadir}/xournalpp/
%{_datadir}/icons/hicolor/*/apps/*
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/*.thumbnailer

%files lang -f xournalpp.lang

%changelog
* Sun Apr 26 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.18:
  * Fixed a crash occurring when recent file entries are invalid
    (gh#xournalpp/xournalpp#1730)
  * Fixed translations not being built correctly, causing
    packaging issues (gh#xournalpp/xournalpp#1596)
  * Fixed background PDF outlines not being saved in exported PDF
    (only available when compiled with Cairo 1.16 or newer)
  * Fixed a deadlock occurring when a second PDF with an outline
    is opened (gh#xournalpp/xournalpp#1582).
  * Fixed the settings file being written to when it is parsed
    (gh#xournalpp/xournalpp#1074)
  * Fixed dark mode icons not loading properly
    (gh#xournalpp/xournalpp#1767)
  * Added missing dark mode icons (gh#xournalpp/xournalpp#1765)
  * Fixed crash in Export As ... on some page range options
    (gh#xournalpp/xournalpp#1790)
  * Fixed crash caused by custom colors in toolbar being "too
    close" (gh#xournalpp/xournalpp#1659)
- No longer need to build translations independently after
  running make.
* Wed Feb 19 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.17:
  - Fixed arrow tip scaling: now scales with thickness instead of
    length (gh#xournalpp/xournalpp#967).
  - Changed coordinate draw direction.
  - Fixed audio playback failures not showing error messages to
    the user (gh#xournalpp/xournalpp#1573).
  - Fixed text tool bold shortcut not working when capslock is
    enabled (gh#xournalpp/xournalpp#1583).
  - Fixed sidebar preview context menu "Move Page Up" and "Move
    Page Down" buttons not being disabled on the first and last
    page, respectively (gh#xournalpp/xournalpp#1637).
  - Fixed Enter keypress on the "Goto Page" (Ctrl-G) dialog not
    changing the page (gh#xournalpp/xournalpp#975).
  - Fixed missing Xournal++ icon errors on most of the dialog
    windows (gh#xournalpp/xournalpp#1667).
- Build translations during make stage.
- Use %%cmake_build instead of obsolete %%make_jobs.
* Tue Dec 17 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.16:
  * Fixed currently editing textboxes not exporting to PDF.
  * Fixed line tool breaking when snap-to-grid is disabled.
- Changes from version 1.0.15 and 1.0.14:
  * Fixed an issue where copying and pasting strokes would crash
    the program.
  * Text field bugfixes
  * Latex tool enhancements
  * Image tool bugfixes
  * Misc quality-of-life enhancements
  * New experimental floating toolbox
  * Improved input handling, bugfixes
  * Updated preferences window
  * Fixed some crashing issues
  * Refactoring and other non-user visible changes
  * Other misc features and bugfixes
- Add xournalpp-fix-desktop-categories.patch: Fix desktop
  categories with additional keywords to prevent "No sufficient
  Category definition" error from brp-desktop.
* Sat Jun 15 2019 aloisio@gmx.com
- Update to version 1.0.12
  * Added new experimental input system that should fix a lot of
    issues related to input handling (can be enabled from
    Preferences > Input System).
  * Added experimental stroke filter (can be enabled in
    Preferences > Drawing Area) to allow selections using drawing
    tool
  * Added ability to double click on selected objects (e.g. text
    fields and LaTeX) to begin editing them (only available with
    the new input system enabled)
  * Fixed some issues with selections
  * Fixed some issues involving autosaving
  * Improved LaTeX editor experience, as well as bug fixes
  * Fixed text editor copying and pasting to the wrong clipboard
  * Fixed many zoom issues while in presentation mode
  * Fixed some other miscellaneous issues
- Use package name in the tarball
* Wed Apr 17 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.10:
  * Support for a new, future file format.
  * Lots of bug fixes and improvements.
- Drop xournalpp-fix-horizontal-space.patch: incorporated
  upstream.
- New BuildRequires: pkgconfig(libzip).
* Tue Feb 19 2019 badshah400@gmail.com
- Update to version 1.0.8:
  * Audio recording directly integrated, no VLC etc. needed.
  * LaTex use now vector graphics.
  * Multiple page layout.
  * Minor bug fixes.
- Add xournalpp-fix-horizontal-space.patch: fix adding horizontal
  space to document view from preferences; patch taken from
  upstream commit (gh#xournalpp/xournalpp#906).
- New upstream build dependencies: pkgconfig(portaudiocpp),
  pkgconfig(sndfile).
* Mon Jan 28 2019 Atri Bhattacharya <badshah400@gmail.com>
- Drop unnecessary Requires(pre/post) on desktop-file-utils.
* Thu Jan 24 2019 Jan Engelhardt <jengelh@inai.de>
- Remove future goals.
* Mon Jan 21 2019 badshah400@gmail.com
- Update to version 1.0.7:
  * Fixes for HiDPI (gh#xournalpp/xournalpp#172).
  * Drop bundled mathtex, thereby fixing a licensing issue
    (mathtex is licensed under GPL-3.0,
    gh#xournalpp/xournalpp#771).
  * Other minor bug fixes.
* Sun Dec 30 2018 badshah400@gmail.com
- Initial package (version 1.0.5).
